# -*- coding: utf-8 -*-

import sys
import os
import subprocess

exit_code = subprocess.call(
    ['/Users/bibektemp/Documents/obfuscation_exmp/.venv/bin/python', '-W', 'ignore', '/Users/bibektemp/Documents/obfuscation_exmp/.venv/lib/python3.12/site-packages/nuitka/build/inline_copy/bin/scons.py', '--quiet', '-f', '/Users/bibektemp/Documents/obfuscation_exmp/.venv/lib/python3.12/site-packages/nuitka/build/Backend.scons', '--jobs', '8', '--warn=no-deprecated', '--no-site-dir', 'nuitka_src=/Users/bibektemp/Documents/obfuscation_exmp/.venv/lib/python3.12/site-packages/nuitka/build', 'python_version=3.12', 'python_prefix=/Users/bibektemp/.local/share/uv/python/cpython-3.12.10-macos-aarch64-none', 'experimental=', 'debug_modes=', 'deployment=false', 'no_deployment=', 'clang_mode=true', 'noelf_mode=true', 'macos_min_version=11.0', 'macos_target_arch=arm64', 'target_arch=arm64', 'module_mode=true', 'dll_mode=false', 'exe_mode=false', 'gil_mode=true', 'source_dir=.', 'nuitka_python=false', 'debug_mode=false', 'debugger_mode=false', 'python_debug=false', 'full_compat=false', 'trace_mode=false', 'file_reference_mode=runtime', 'compiled_module_count=1', 'result_exe=/Users/bibektemp/Documents/obfuscation_exmp/src/fount_eda/edaclass.cpython-312-darwin.so'],
    env={'COMMAND_MODE': 'unix2003','CURSOR_TRACE_ID': 'd6b3c4f9530244c1ae5bf88b00032c88','HOME': '/Users/bibektemp','LOGNAME': 'bibektemp','MallocNanoZone': '0','ORIGINAL_XDG_CURRENT_DESKTOP': 'undefined','OSLogRateLimit': '64','PATH': '/Users/bibektemp/Documents/obfuscation_exmp/.venv/bin:/opt/homebrew/opt/postgresql@12/bin:/Users/bibektemp/.local/bin:/opt/homebrew/opt/mongodb-community@4.4/bin:/opt/homebrew/opt/postgresql@12/bin:/opt/homebrew/bin:/opt/homebrew/sbin:/usr/local/bin:/System/Cryptexes/App/usr/bin:/usr/bin:/bin:/usr/sbin:/sbin:/var/run/com.apple.security.cryptexd/codex.system/bootstrap/usr/local/bin:/var/run/com.apple.security.cryptexd/codex.system/bootstrap/usr/bin:/var/run/com.apple.security.cryptexd/codex.system/bootstrap/usr/appleinternal/bin:/Users/bibektemp/.cargo/bin:/Users/bibektemp/.cursor/extensions/ms-python.debugpy-2025.10.0-darwin-arm64/bundled/scripts/noConfigScripts','SHELL': '/bin/zsh','SSH_AUTH_SOCK': '/private/tmp/com.apple.launchd.V76q9B6Yn5/Listeners','TMPDIR': '/var/folders/tj/3s_1lcp956l_trcr48579zlh0000gp/T/','USER': 'bibektemp','XPC_FLAGS': '0x0','XPC_SERVICE_NAME': '0','__CFBundleIdentifier': 'com.todesktop.230313mzl4w4u92','__CF_USER_TEXT_ENCODING': '0x1F6:0x0:0x0','LANG': 'en_US.UTF-8','PYDEVD_DISABLE_FILE_VALIDATION': '1','BUNDLED_DEBUGPY_PATH': '/Users/bibektemp/.cursor/extensions/ms-python.debugpy-2025.10.0-darwin-arm64/bundled/libs/debugpy','ZDOTDIR': '/Users/bibektemp','USER_ZDOTDIR': '/Users/bibektemp','PWD': '/Users/bibektemp/Documents/obfuscation_exmp','SHLVL': '1','OLDPWD': '/Users/bibektemp/Documents/obfuscation_exmp','HOMEBREW_PREFIX': '/opt/homebrew','HOMEBREW_CELLAR': '/opt/homebrew/Cellar','HOMEBREW_REPOSITORY': '/opt/homebrew','INFOPATH': '/opt/homebrew/share/info:','VIRTUAL_ENV': '/Users/bibektemp/Documents/obfuscation_exmp/.venv','VIRTUAL_ENV_PROMPT': '(obfuscation-exmp) ','PS1': '(obfuscation-exmp) %n@%m %1~ %# ','_': '/Users/bibektemp/Documents/obfuscation_exmp/.venv/bin/nuitka','PYTHONHASHSEED': '0','NUITKA_PYTHON_EXE_PATH': '/Users/bibektemp/Documents/obfuscation_exmp/.venv/bin/python','NUITKA_PACKAGE_DIR': '/Users/bibektemp/Documents/obfuscation_exmp/.venv/lib/python3.12/site-packages/nuitka','_NUITKA_BUILD_DEFINITIONS_CATALOG': '_NUITKA_BUILD_DEFINITIONS_CATALOG','NUITKA_QUIET': '0'},
    shell=False
)